@@ -73,9 +73,9 @@ pub struct App {
 
 impl App {
 	pub async fn new() -> Result<App, std::io::Error> {
-		let (opt_files, opt_globpaths, opt_debug_window, opt_timeline_steps) = {
+		let (opt_files, opt_globpaths, opt_debug_window, opt_timeline_steps, opt_currency_token_rate, opt_currency_symbol) = {
 			let opt = OPT.lock().unwrap();
-			(opt.files.clone(), opt.glob_paths.clone(), opt.debug_window, opt.timeline_steps)
+			(opt.files.clone(), opt.glob_paths.clone(), opt.debug_window, opt.timeline_steps, opt.currency_token_rate, opt.currency_symbol.clone())
 		};
 
 		let mut app = App {
@@ -87,6 +87,12 @@ impl App {
 			next_glob_scan: None,
 		};
 
+		if opt_currency_token_rate > 0.0 {
+			app.dash_state.currency_per_token = Some(opt_currency_token_rate);
+			app.dash_state.currency_symbol = opt_currency_symbol;
+			app.dash_state.ui_uses_currency = true;
+		}
+
 		if opt_files.is_empty() && opt_globpaths.is_empty() {
 			eprintln!("{}: no logfile(s) or 'glob' paths provided.", Opt::clap().get_name());
 			return exit_with_usage("missing logfiles");
@@ -769,7 +775,6 @@ lazy_static::lazy_static! {
 #[derive(Clone, Default, Debug, Serialize, Deserialize)]
 pub enum NodeStatus {
 	Started,
-	Connecting,
 	Connected,
 	#[default]
 	Stopped,
@@ -777,7 +782,6 @@ pub enum NodeStatus {
 
 pub fn node_status_as_string(node_status: &NodeStatus) -> String {
 	match node_status {
-		NodeStatus::Connecting => "Connecting".to_string(),
 		NodeStatus::Connected => "Connected".to_string(),
 		NodeStatus::Stopped => "Stopped".to_string(),
 		NodeStatus::Started => "Started".to_string(),
@@ -1037,11 +1041,7 @@ impl NodeMetrics {
 	///! Process a logfile entry
 	///! Returns true if the line has been processed and can be discarded
 	pub fn process_logfile_entry(&mut self, line: &String, entry_metadata: &LogMeta) -> bool {
-		return self.parse_data_response(
-			&line,
-			"Running as Node: SendToSection [ msg: MsgEnvelope { message: QueryResponse { response: QueryResponse::",
-		)
-		|| self.parse_timed_data(&line, &entry_metadata.message_time)
+		return self.parse_timed_data(&line, &entry_metadata.message_time)
 		|| self.parse_states(&line, &entry_metadata)
 		|| self.parse_start(&line, &entry_metadata);
 	}
@@ -1055,7 +1055,7 @@ impl NodeMetrics {
 			self.count_put(&entry_time);
 			self.node_status = NodeStatus::Connected;
 			return true;
-		} else if line.contains("Editing Register success") {
+		} else if line.contains("Editing Register success") {	// TODO: no longer present, find new log message
 			self.count_put(&entry_time);
 			self.node_status = NodeStatus::Connected;
 			return true;
@@ -1083,29 +1083,6 @@ impl NodeMetrics {
 		return false;
 	}
 
-	///! Update data metrics from a handler response logfile entry
-	///! Returns true if the line has been processed and can be discarded
-	fn parse_data_response(&mut self, line: &String, pattern: &str) -> bool {
-		if let Some(mut response_start) = line.find(pattern) {
-			response_start += pattern.len();
-			let mut response = "";
-
-			if let Some(response_end) = line[response_start..].find(",") {
-				response = line.as_str()[response_start..response_start + response_end]
-					.as_ref();
-				if !response.is_empty() {
-					self.parser_output = format!("node activity: {}", response);
-				}
-			}
-			if response.is_empty() {
-				self.parser_output = format!("failed to parse_data_response: {}", line);
-			};
-
-			return true;
-		};
-		return false;
-	}
-
 	///! Update data metrics from a handler response logfile entry
 	///! Returns true if the line has been processed and can be discarded
 	fn parse_string(&mut self, prefix: &str, line: &String) -> Option<String> {
@@ -1136,18 +1113,6 @@ impl NodeMetrics {
 		let &content = &line.as_str();
 
 		// Node Status
-		if content.contains("Getting closest peers") {
-			self.node_status = NodeStatus::Connecting;
-			self.parser_output = String::from("Node status: Connecting");
-			return true;
-		}
-
-		if content.contains("Connected to the Network") {
-			self.node_status = NodeStatus::Connected; // Also set by some other matches
-			self.parser_output = String::from("Node status: Connected");
-			return true;
-		}
-
 		if content.contains("Node events channel closed") {
 			self.node_status = NodeStatus::Stopped;
 			self.parser_output = String::from("Node status: Disconnected");
@@ -1166,14 +1131,14 @@ impl NodeMetrics {
 			return true;
 		}
 
-		if content.contains("Skipping ") {
-			let mut parser_output = String::from("Connected ({} lag)");
-			if let Some(events_skipped) = self.parse_usize("Skipping ", content) {
-				parser_output = format!("{} ({})", &parser_output, events_skipped);
-			};
-			self.parser_output = parser_output;
-			return true;
-		}
+		// if content.contains("Skipping ") {
+		// 	let mut parser_output = String::from("Connected ({} lag)");
+		// 	if let Some(events_skipped) = self.parse_usize("Skipping ", content) {
+		// 		parser_output = format!("{} ({})", &parser_output, events_skipped);
+		// 	};
+		// 	self.parser_output = parser_output;
+		// 	return true;
+		// }
 
 		// Metrics
 		if content.contains("sn_logging::metrics") {
@@ -1270,21 +1235,21 @@ impl NodeMetrics {
 		false
 	}
 
-	fn parse_usize(&mut self, prefix: &str, content: &str) -> Option<usize> {
-		if let Some(position) = content.find(prefix) {
-			let word: Vec<&str> = content[position + prefix.len()..]
-				.trim()
-				.splitn(2, |c| c == ' ' || c == ',' || c== '}')
-				.collect();
-			if word.len() > 0 {
-				match word[0].parse::<usize>() {
-					Ok(value) => return Some(value),
-					Err(_e) => self.parser_output = format!("failed to parse '{}' as usize from: '{}'", word[0], &content[position + prefix.len()..]),
-				}
-			}
-		}
-		None
-	}
+	// fn parse_usize(&mut self, prefix: &str, content: &str) -> Option<usize> {
+	// 	if let Some(position) = content.find(prefix) {
+	// 		let word: Vec<&str> = content[position + prefix.len()..]
+	// 			.trim()
+	// 			.splitn(2, |c| c == ' ' || c == ',' || c== '}')
+	// 			.collect();
+	// 		if word.len() > 0 {
+	// 			match word[0].parse::<usize>() {
+	// 				Ok(value) => return Some(value),
+	// 				Err(_e) => self.parser_output = format!("failed to parse '{}' as usize from: '{}'", word[0], &content[position + prefix.len()..]),
+	// 			}
+	// 		}
+	// 	}
+	// 	None
+	// }
 
 	fn parse_u64(&mut self, prefix: &str, content: &str) -> Option<u64> {
 		if let Some(position) = content.find(prefix) {
@@ -1470,6 +1435,10 @@ pub struct DashState {
 	pub logfile_names_sorted: Vec<String>,
 	pub logfile_names_sorted_ascending: bool,
 
+	pub currency_symbol: String,
+	pub currency_per_token: Option<f32>,
+	pub ui_uses_currency: bool,
+
 	pub active_timescale: usize,
 	pub node_logfile_visible: bool,
 	pub dash_node_focus: String,
@@ -1506,6 +1475,10 @@ impl DashState {
 			logfile_names_sorted: Vec::<String>::new(),	// Sorted by column
 			logfile_names_sorted_ascending: true,
 
+			currency_symbol: String::from(""),
+			currency_per_token: None,
+			ui_uses_currency: false,
+
 			active_timescale: 0,
 			node_logfile_visible: true,
 			dash_node_focus: String::new(),
